@@ -1,9 +1,9 @@
 <?php
 // show details of control
-// $Id: control.php,v 2.2.12.1 2004/04/07 09:16:14 turbo Exp $
+// $Id: control.php,v 2.4 2005/02/24 17:04:00 turbo Exp $
 //
 require("./include/pql_config.inc");
-include("./header.html");
+include($_SESSION["path"]."/header.html");
 ?>
 <span class="title1">Server Control</span>
 <br>
